#
# spec file for package traceroute
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           traceroute
Version:        2.1.5
Release:        1.5
Summary:        Packet route path tracing utility
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            https://traceroute.sourceforge.net/
Source:         https://sourceforge.net/projects/traceroute/files/traceroute/traceroute-%{version}/%{name}-%{version}.tar.gz
Patch0:         traceroute-autotools.patch
Patch1:         traceroute-secure_getenv.patch
BuildRequires:  automake
Provides:       tcptraceroute = %{version}
Obsoletes:      tcptraceroute <= 1.5.beta7
Provides:       net-tools:%{_sbindir}/%{name}

%description
Traceroute tracks the route packets taken from an IP network on their way to a given host.
It utilizes the IP protocol's time to live (TTL) field and attempts to elicit an ICMP TIME_EXCEEDED
response from each gateway along the path to the host.

%prep
%autosetup -p1

%build
export LDFLAGS="-Wl,-z,relro,-z,now"
autoreconf -fiv
%configure
%make_build

%install
%make_install
ln -sf %{_sbindir}/%{name} %{buildroot}%{_sbindir}/%{name}6
ln -s %{_mandir}/man8/traceroute.8 %{buildroot}%{_mandir}/man8/traceroute6.8
install -D -m0755 wrappers/tcptraceroute %{buildroot}%{_bindir}/tcptraceroute
install -m0644 wrappers/tcptraceroute.8 %{buildroot}%{_mandir}/man8/tcptraceroute.8

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/*
%{_sbindir}/*
%{_mandir}/man8/*.8%{?ext_man}

%changelog
* Tue Dec 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 2.1.5:
  * Parse interface information (rfc5837) for ICMP extensions
  * Add `fastopen' tcp module option (cookie negotiation only)
  * Complete tcp module option `mss' to discover possible mss
    clamping along the path being traced.
  * Complete tcp module option `info' to print returned tcp header
    options too (all those that can be set or altered by `-O' for
    tcp module).
* Fri Nov 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.1.3:
  * Fix command line parsing in wrappers. (CVE-2023-46316 bsc#1216591)
* Tue Feb 14 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to version 2.1.2:
  * Fix unprivileged ICMP tracerouting with Linux kernel >= 6.1
* Wed Dec 28 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to version 2.1.1:
  * Interpret ipv4-mapped ipv6 addresses (::ffff:A.B.C.D) as true
    ipv4
  * Return back more robust poll(2) loop handling
* Tue Jan 22 2019 Jan Engelhardt <jengelh@inai.de>
- Trim time-sensitive wording from description.
* Tue Jan 15 2019 Cristian Rodríguez <crrodriguez@opensuse.org>
- fix undefined reference to "ceil", some compiler versions do
  not optimize-out or inline ceil, but anyways libm is required.
* Tue Jan  8 2019 Cristian Rodríguez <crrodriguez@opensuse.org>
- Update to version 2.1.0
  * Implement -w MAX_SECS,HERE,NEAR option
  * Provide tcptraceroute
  * Improve the main loop for better interactivity.
* Thu Jul 16 2015 crrodriguez@opensuse.org
- traceroute-autotools.patch: switch to non-recursive automake
  without libtool.
* Thu Jul 16 2015 crrodriguez@opensuse.org
- Version 2.0.21
  * fix -F --mtu with current kernel versions
- traceroute-autotools.patch refresh and add -fvisibility=hidden
  to CFLAGS.
* Sun Aug 31 2014 crrodriguez@opensuse.org
- version 2.0.20
  * Describe all complementary long options in the man page
  * Use correct service name for AS lookups
  * Avoid some rare case null dereference
  * Improve expiration check for simultaneous probes
- traceroute-secure_getenv.patch use secure_getenv
- traceroute-autotools.patch refresh
* Thu Mar  7 2013 crrodriguez@opensuse.org
- The previous incarnation of traceroute had a traceroute6
  binary, provide a compatibility symlink for it.
- Build with full RELRO.
* Sun Jan 27 2013 crrodriguez@opensuse.org
- Initial version. obsoletes the version found in package net-tools
- This is the implementation used by the rest of the planet, not
  the one found in SUSE but Fedora, RHEL, Debian, Mandriva, Gentoo, Ubuntu.
